@@ -20,12 +20,13 @@ import shutil
 import operator
 import warnings
 import tempfile
+from datetime import datetime
 from typing import List, Union
 from .Status import Status
 from .Note import Note
 from . import Content
 
-import xml.etree.ElementTree as ET
+import lxml.etree as ET
 from inspect import getmembers, isclass
 
 
@@ -50,7 +51,7 @@ class MediaReview:
         """
         self.media = Path(media)
 
-        self.status = status
+        self.status = status or Status("waiting review", "default")
 
         self.notes = []
         if notes:
@@ -58,20 +59,6 @@ class MediaReview:
 
         self.metadata = metadata or {}
 
-    @property
-    def status(self):
-        if self._status_history:
-            return self._status_history[-1]
-
-    @status.setter
-    def status(self, value):
-        if value and value.date not in [d.date for d in self._status_history]:
-            self._status_history.append(value)
-            # Sort statuses by date
-            self._status_history = sorted(
-                self._status_history, key=operator.attrgetter("date")
-            )
-
     def add_note(self, note: Union[Note, List[Note]] = None):
         """Append a note (or all notes if a list is provided) it to the review's notes list.
 
@@ -136,9 +123,10 @@ class MediaReview:
 
         :return: Note
         """
-        for n in self.notes:
-            if n.date == date:
-                return n
+        if date:
+            for n in self.notes:
+                if n.date == datetime.fromisoformat(date):
+                    return n
 
     def write(
         self, path: Union[str, Path] = "", include_attached_files: bool = True
@@ -182,12 +170,24 @@ class MediaReview:
         )
 
         # Statuses
+        # --------
+        # History
         statuses = ET.SubElement(review, "statuses")
         for s in self.get_status_history():
-            status = ET.Element("status", {"date": s.date, "author": s.author})
+            status = ET.Element(
+                "status", {"date": s.date.isoformat(), "author": s.author}
+            )
             status.text = s.state
             statuses.append(status)
 
+        # Current
+        status = ET.Element(
+            "status",
+            {"date": self.status.date.isoformat(), "author": self.status.author},
+        )
+        status.text = self.status.state
+        statuses.append(status)
+
         # Notes
         notes = ET.SubElement(review, "notes")
         files_to_copy = []
@@ -195,9 +195,9 @@ class MediaReview:
             note = ET.Element(
                 "note",
                 {
-                    "date": n.date,
+                    "date": n.date.isoformat(),
                     "author": n.author,
-                    "parent": n.parent.date if n.parent else "",
+                    "parent": n.parent.date.isoformat() if n.parent else "",
                 },
             )
 
@@ -217,7 +217,8 @@ class MediaReview:
 
                             # Set attribute's value as relative
                             relative_path = Path(
-                                n.date.replace(":", "_"), Path(image_path).name
+                                n.date.isoformat().replace(":", "_"),
+                                Path(image_path).name,
                             )
                             params[attribute] = str(relative_path)
                             # Keep files to copy
@@ -247,14 +248,11 @@ class MediaReview:
 
         # Write to file
         # create a new XML file with the results
-        from xml.dom import minidom
+        xml = ET.ElementTree(review)
 
-        xmlstr = minidom.parseString(ET.tostring(review, encoding="utf-8")).toprettyxml(
-            indent="   "
-        )
         file = review_folder.joinpath("review.orio")
-        with file.open("w") as f:
-            f.write(xmlstr)
+        with file.open("wb") as f:
+            xml.write(f, encoding="utf-8", xml_declaration=True, pretty_print=True)
 
         # Copy files if they have to be copied
         for source, target in files_to_copy:
